/* ----------------------------------------------------------
                           keypad.c

     Softwaremodul fuer das Einlesen von 4 (als Gamepad
     angeordnete) Tasten.

     Ein Doppelklicken der Taste nach oben wird als
     Enter ausgewertet.

     Anschlussbelegeung der Tasten in keypad.h

     MCU   :
     Takt  :


     07.03.2020  R. Seelig
   ---------------------------------------------------------- */

#include "keypad.h"


/* -------------------------------------------------------
                       key_init

     Initialisiert die GPIO-Anschluesse an die die Tasten
     angeschlossen sind als Eingaenge
   ------------------------------------------------------- */
void key_init(void)
{
  keyright_init();
  keyup_init();
  keyleft_init();
  keydwn_init();
}

/* -------------------------------------------------------
                        key_get

     wartet auf einen Tastendruck und gibt den Wert der
     Taste zurueck.

     Rueckgabe: Tastenwert  Funktion
                    1 ------ Taste oben
                    2 ------ Taste links
                    3 ------ Taste rechts
                    4 ------ Taste unten
                    5 ------ Doppelt gedrueckte Taste
                             oben (Enter)
   ------------------------------------------------------- */
uint8_t key_get(void)
{
  uint8_t  result = 0;
  uint32_t tcount;
  uint8_t  doubleklick;

  while (!result)
  {
    if (is_keyup())
    {
      delay(entpr_time);
      while(is_keyup());
      delay(entpr_time);

      // erfassen, ob ein doppeltes Betaetigen des Tasters erfolgt ist
      tcount= 0;
      doubleklick= 0;
      while ((tcount< double_klicktime) && (!doubleklick))
      {
        if (is_keyup()) doubleklick= 1;
        tcount++;
        delay(1);
      }

      if (doubleklick)
      {
        delay(entpr_time);
        while(is_keyup());
        delay(entpr_time);
        result= ENTER;
      }
      else
      {
        result= UP;
      }
    }
    if (is_keyleft())
    {
      delay(entpr_time);
      while(is_keyleft());
      delay(entpr_time);
      result= LEFT;
    }
    if (is_keyright())
    {
      delay(entpr_time);
      while(is_keyright());
      delay(entpr_time);
      result= RIGHT;
    }
    if (is_keydwn())
    {
      delay(entpr_time);
      while(is_keydwn());
      delay(entpr_time);
      result= DOWN;
    }
  }
  return result;
}
